summaryrefslogtreecommitdiff
path: root/source3/rpc_client/cli_winreg_int.h
diff options
context:
space:
mode:
Diffstat (limited to 'source3/rpc_client/cli_winreg_int.h')
-rw-r--r--source3/rpc_client/cli_winreg_int.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/rpc_client/cli_winreg_int.h b/source3/rpc_client/cli_winreg_int.h
index f991559cba..b979988882 100644
--- a/source3/rpc_client/cli_winreg_int.h
+++ b/source3/rpc_client/cli_winreg_int.h
@@ -29,7 +29,7 @@
*
* @param[in] mem_ctx The memory context to use.
*
* @param[in] server_info The supplied server info.
*
* @param[in] key The key to open. This needs to start with the name
* of the hive like HKLM.
@@ -85,7 +85,7 @@ NTSTATUS dcerpc_winreg_int_openkey(TALLOC_CTX *mem_ctx,
* code if something gone wrong.
*/
NTSTATUS dcerpc_winreg_int_hklm_openkey(TALLOC_CTX *mem_ctx,
- const struct auth_serversupplied_info *server_info,
+ const struct auth_serversupplied_info *session_info,
struct messaging_context *msg_ctx,
struct dcerpc_binding_handle **h,
const char *key,
@@ -29,7 +29,7 @@
* @param[in] mem_ctx The memory context to use.
*
- * @param[in] server_info The supplied server info.
+ * @param[in] session_info The supplied server info.
*
* @param[in] key The key to open. This needs to start with the name